@@ -17,7 +17,9 @@ def lookup_chord(root: Union[str, int], chord: str, **kwargs) -> List[int]:
     return [midi_root + note for note in base_notes]
 
 
-def invert_chord(chord_notes: List[int], inversions: List[int] = [], **kwargs) -> List[str]:
+def invert_chord(
+    chord_notes: List[int], inversions: List[int] = [], **kwargs
+) -> List[str]:
     """
     Given a list of chord notes and a list of inversions, return an inverted chord
     """
@@ -44,7 +46,9 @@ def stack_chord(chord_notes: List[int], stack: int = 0, **kwargs):
     return list(sorted(list(set(stacked_chord + chord_notes))))
 
 
-def midi_chord(root: Union[str, int], chord="MIN_6_9", inversions=[], stack=0, **kwargs):
+def midi_chord(
+    root: Union[str, int], chord="MIN_6_9", inversions=[], stack=0, **kwargs
+):
     """
     Given a chord root, chord name, list of inversions, and a number and direction to stack, generate a chord.
     """
